<?php
/**
 * Plugin Name: Mimoza İletişim Eklentisi
 * Plugin URI: https://mimozabilisim.com/wordPress-eklentileri/
 * Description: Telefon, WhatsApp ve Messenger ile bağlantı kuran ve özelleştirilebilir renk seçenekleri sunan bir WordPress eklentisi.
 * Version: 1.0
 * Author: Onur Kalafat
 * Author URI: https://mimozabilisim.com/
 * Text Domain: mimoza-iletisim
 */

// CSS ve JS dosyalarını yükleme
function mimoza_iletisim_enqueue_assets() {
    wp_enqueue_style('mimoza-iletisim-css', plugin_dir_url(__FILE__) . 'mimoza-iletisim.css');
    wp_enqueue_script('mimoza-iletisim-js', plugin_dir_url(__FILE__) . 'mimoza-iletisim.js', array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'mimoza_iletisim_enqueue_assets');

// Admin menüsüne eklenti ayarları sayfası ekleme
function mimoza_iletisim_menu() {
    add_menu_page(
        'Mimoza İletişim Ayarları', // Sayfa başlığı
        'Mimoza İletişim', // Menü başlığı
        'manage_options', // Yetki kontrolü (sadece admin görecek)
        'mimoza-iletisim', // Menü slug
        'mimoza_iletisim_settings_page', // Ayar sayfasını yükleyecek fonksiyon
        'dashicons-email-alt', // Menüdeki ikon (WordPress Dashicons kullanabilirsiniz)
        100 // Menü sıralaması
    );
}
add_action('admin_menu', 'mimoza_iletisim_menu');

// Admin ayar sayfası içeriği
function mimoza_iletisim_settings_page() {
    if (!current_user_can('manage_options')) {
        return;
    }

    // Form gönderildiğinde verileri kaydetme
    if (isset($_POST['submit'])) {
        update_option('mimoza_iletisim_phone', sanitize_text_field($_POST['phone']));
        update_option('mimoza_iletisim_whatsapp', sanitize_text_field($_POST['whatsapp']));
        update_option('mimoza_iletisim_messenger', sanitize_text_field($_POST['messenger']));
        update_option('mimoza_iletisim_color', sanitize_hex_color($_POST['color']));
        update_option('mimoza_iletisim_position', sanitize_text_field($_POST['position']));
    }

    // Kaydedilen verileri al
    $phone = get_option('mimoza_iletisim_phone', '');
    $whatsapp = get_option('mimoza_iletisim_whatsapp', '');
    $messenger = get_option('mimoza_iletisim_messenger', '');
    $color = get_option('mimoza_iletisim_color', '#000000');
    $position = get_option('mimoza_iletisim_position', 'right');

    ?>
    <div class="wrap">
        <h1>Mimoza İletişim Ayarları</h1>
        <form method="POST">
            <table class="form-table">
                <tr>
                    <th scope="row"><label for="phone">Telefon Numarası</label></th>
                    <td><input type="text" id="phone" name="phone" value="<?php echo esc_attr($phone); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row"><label for="whatsapp">WhatsApp Numarası</label></th>
                    <td><input type="text" id="whatsapp" name="whatsapp" value="<?php echo esc_attr($whatsapp); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row"><label for="messenger">Messenger Kullanıcı Adı</label></th>
                    <td><input type="text" id="messenger" name="messenger" value="<?php echo esc_attr($messenger); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row"><label for="color">Renk Seçimi</label></th>
                    <td><input type="color" id="color" name="color" value="<?php echo esc_attr($color); ?>" /></td>
                </tr>
                <tr>
                    <th scope="row"><label for="position">Buton Pozisyonu</label></th>
                    <td>
                        <select id="position" name="position">
                            <option value="right" <?php selected($position, 'right'); ?>>Sağ Alt</option>
                            <option value="left" <?php selected($position, 'left'); ?>>Sol Alt</option>
                            <option value="center" <?php selected($position, 'center'); ?>>Alt Orta</option>
                        </select>
                    </td>
                </tr>
            </table>
            <input type="submit" name="submit" value="Kaydet" class="button button-primary" />
        </form>
    </div>
    <?php
}

// Kullanıcı iletişim bilgilerini ekranda gösterme
function mimoza_iletisim_display_buttons() {
    // Kaydedilen verileri al
    $phone = get_option('mimoza_iletisim_phone', '');
    $whatsapp = get_option('mimoza_iletisim_whatsapp', '');
    $messenger = get_option('mimoza_iletisim_messenger', '');
    $color = get_option('mimoza_iletisim_color', '#000000');
    $position = get_option('mimoza_iletisim_position', 'right');

    ?>
    <div class="mimoza-contact-buttons <?php echo esc_attr($position); ?>" style="color: <?php echo esc_attr($color); ?>">
        <?php if ($phone): ?>
            <a href="tel:<?php echo esc_attr($phone); ?>" class="contact-button">📞 Telefon</a>
        <?php endif; ?>
        <?php if ($whatsapp): ?>
            <a href="https://wa.me/<?php echo esc_attr($whatsapp); ?>" class="contact-button">💬 WhatsApp</a>
        <?php endif; ?>
        <?php if ($messenger): ?>
            <a href="https://m.me/<?php echo esc_attr($messenger); ?>" class="contact-button">📩 Messenger</a>
        <?php endif; ?>
    </div>
    <?php
}
add_action('wp_footer', 'mimoza_iletisim_display_buttons');
